package com.annahid.games.example.scenes;

import com.annahid.libs.artenus.Artenus;
import com.annahid.libs.artenus.core.Scene;
import com.annahid.libs.artenus.core.Stage;
import com.annahid.libs.artenus.data.RGB;
import com.annahid.libs.artenus.graphics.TextureManager;
import com.annahid.libs.artenus.graphics.effects.DropShadow;
import com.annahid.libs.artenus.graphics.sprites.ImageSprite;
import com.annahid.libs.artenus.graphics.sprites.TextSprite;
import com.annahid.games.example.R;
import com.annahid.libs.artenus.input.Button;
import com.annahid.libs.artenus.input.ButtonListener;
import com.annahid.libs.artenus.input.TouchButton;

/**
 * This is the first scene that appears on the screen.
 */
public class MenuScene extends Scene implements ButtonListener {
    public MenuScene(Stage parentStage) {
        super(parentStage);
        setBackColor(new RGB("44aaff"));
    }

    /**
     * Play button
     */
    private TouchButton playButton;

    /**
     * This method is called by the framework when all textures are in place and it is safe
     * to build the scene. Create all sprites here.
     * ALWAYS CALL THE SUPERCLASS METHOD AT THE END (AND NOT THE BEGINNING).
     */
    @Override
    public void onLoaded() {
        TextSprite welcomeText = new TextSprite(
                TextureManager.getFont(R.raw.font_letters), // Font texture
                40, // Font size
                "Welcome to Artenus!" // Initial text
        );

        welcomeText.centerAt(stage.getLogicalWidth() / 2, 50);
        add(new DropShadow(welcomeText).setOffset(2, 2));

        ImageSprite playSprite = new ImageSprite(R.raw.play, new ImageSprite.Cutout(160, 160, 1));
        playSprite.setPosition(stage.getLogicalWidth() / 2, stage.getLogicalHeight() / 2);

        playButton = new TouchButton(
                new DropShadow(playSprite).setShadowAlpha(0.3f).setOffset(4, 5)
        );
        playButton.setListener(this);
        playButton.setScale(0.9f);
        add(playButton);

        super.onLoaded();
    }

    /**
     * Called by the framework for each frame, to advance the animation.
     * ALWAYS CALL THE SUPERCLASS METHOD.
     *
     * @param elapsedTime The time elapsed since last frame
     */
    @Override
    public void advance(float elapsedTime) {
        super.advance(elapsedTime);

        if (playButton.isPressed()) {
            // Zoom the button in when pressed
            playButton.setScale(Math.min(1, playButton.getScale().x + elapsedTime));
        } else {
            // Zoom the button out when not pressed
            playButton.setScale(Math.max(0.9f, playButton.getScale().x - elapsedTime));
        }
    }

    @Override
    public void onPress(Button button) {

    }

    @Override
    public void onRelease(Button button, boolean cancel) {
        if (!cancel) {
            if (button == playButton) {
                stage.setScene(new GameScene(stage));
            }
        }
    }

    /**
     * If you don't implement this method, the user cannot exit your game!
     *
     * @return true
     */
    @Override
    public boolean onBackButton() {
        Artenus.getInstance().exit();
        return true;
    }
}
